@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package WWW::ipinfo;
-$WWW::ipinfo::VERSION = '0.04';
+$WWW::ipinfo::VERSION = '0.05';
 use HTTP::Tiny;
 use 5.008;
 use JSON;
@@ -44,7 +44,7 @@ WWW::ipinfo - Returns your ip address and geolocation data using L<http://ipinfo
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,7 @@ L<WWW::IP> - a module that uses up to 3 services to retrieve your IP address
 
 =head1 CONTRIBUTORS
 
-Jon D Jones III
+John D Jones III
 
 =head1 AUTHOR
 
